@@ -95,6 +95,7 @@ class LoginRequest(DSRequest):
                             KOMPAS_INFORMICA_WS=settings.KOMPAS_INFORMICA_WS,
                             KOMPAS_INFORMICA=settings.KOMPAS_INFORMICA,
                             CKK_CONFIGURATOR=settings.CKK_CONFIGURATOR,
+                            DEFAULT_TIMEOUT=settings.DEFAULT_TIMEOUT,
                             ENABLE_FILE_VIEW=settings.ENABLE_FILE_VIEW,
                             login=login,
                             message_state_delivered_id=Messages_state.message_state_delivered().id,
@@ -111,6 +112,7 @@ class LoginRequest(DSRequest):
                             user__color=user.color if user.color is not None and user.color != 'undefined' else 'black',
                             user_full_name=user.get_full_name,
                             user_short_name=user.get_short_name,
+                            username=user.username,
                             workshops=workshops,
                             userId=user.id,
                             ws_channel=ws_channel,
