@@ -16,19 +16,28 @@ closed = "closed"
 create = "create"
 deleted = "deleted"
 doing = "doing"
+execution="execution"
 formirovanie="formirovanie"
 green = "green"
+handmade = "handmade"
+in_production="in_production"
+launched = "launched"
 made = "made"
 new = "new"
 new_man = "new_man"
+not_relevant = "not_relevant"
 orange = "orange"
+otkryt = "otkryt"
+otmenen = "otmenen"
 red = "red"
 restarted = "restarted"
+route_made="route_made"
 started = "started"
 stoped = "stoped"
 transferred = "transferred"
 update = "update"
 value_odd = "value_odd"
+zakryt = "zakryt"
 
 name_new="Новый"
 name_new_s="Новый (с)"
