@@ -3,8 +3,11 @@ import re
 
 from django.db import connection
 
+from isc_common.number import ToStr
+
 logger = logging.getLogger(__name__)
 
+
 def uncapitalize(str):
     return str[0:1].lower() + str[1:]
 
@@ -20,6 +23,9 @@ def qutes_str(str):
 def delete_dbl_spaces(value):
     if value is None:
         return value
+
+    if not isinstance(value, str):
+        return ToStr(value)
     return re.sub('\s+', ' ', value).strip();
 
 
