@@ -23,7 +23,7 @@ def del_last_zero(value):
 
 
 def DecimalToStr(value):
-    if value == None:
+    if value is None:
         return ''
 
     try:
@@ -37,7 +37,7 @@ def DecimalToStr(value):
 
 
 def StrToNumber(s1):
-    if s1 == None:
+    if s1 is None:
         return None
 
     if s1 == '':
@@ -60,7 +60,7 @@ def StrToNumber(s1):
 
 
 def IntToNumber(s):
-    if s == None:
+    if s is None:
         return None
 
     if not isinstance(s, int):
@@ -70,7 +70,7 @@ def IntToNumber(s):
 
 
 def IntToStr(value):
-    if value == None:
+    if value is None:
         return None
 
     if not isinstance(value, str):
@@ -83,7 +83,7 @@ def IntToStr(value):
 
 
 def ToStr(s):
-    if s == None or s == 'null':
+    if s is None or s == 'null':
         return None
 
     if not isinstance(s, str):
@@ -99,7 +99,7 @@ def ToStr(s):
 
 
 def ToNumber(s):
-    if s == None:
+    if s is None:
         return 0
 
     if isinstance(s, int):
@@ -115,7 +115,7 @@ def ToNumber(s):
 
 
 def ToInt(s):
-    if s == None:
+    if s is None:
         return None
 
     if isinstance(s, int):
@@ -131,7 +131,7 @@ def ToInt(s):
 
 
 def ToDecimal(s):
-    if s == None:
+    if s is None:
         return 0
 
     if isinstance(s, int):
@@ -149,7 +149,7 @@ def ToDecimal(s):
 
 
 def IntToDecimal(s):
-    if s == None:
+    if s is None:
         return None
 
     if not isinstance(s, int):
@@ -159,7 +159,7 @@ def IntToDecimal(s):
 
 
 def StrToInt(s):
-    if s == None:
+    if s is None:
         return None
     try:
         return int(s)
@@ -203,7 +203,7 @@ def model_2_dict(instance, fields=None, exclude=None):
     for f in chain(opts.concrete_fields, opts.private_fields, opts.many_to_many):
         if not getattr(f, 'editable', False):
             continue
-        if fields != None and f.name not in fields:
+        if fields is not None and f.name not in fields:
             continue
         if exclude and f.name in exclude:
             continue
@@ -247,13 +247,13 @@ class Set:
             self._lst = lst
 
     def __str__(self):
-        if self._set != None:
+        if self._set is not None:
             _lst = list(self._set)
             _lst = [str(l) for l in _lst]
 
             _str = ' , '.join(_lst)
             return f'''({_str})'''
-        elif self._lst != None:
+        elif self._lst is not None:
             _lst = [str(l) for l in self._lst]
             _str = ' , '.join(_lst)
             return f'''({_str})'''
@@ -267,9 +267,9 @@ class Set:
 
     @property
     def get_set_sorted_as_original(self):
-        if self._lst != None:
+        if self._lst is not None:
             return sorted(set(self._lst), key=self._lst.index)
-        elif self._set != None:
+        elif self._set is not None:
             return list(self._set)
         else:
             return []
